maite.testing.docs.NumPyDocResults
==================================

.. currentmodule:: maite.testing.docs

.. autoclass:: NumPyDocResults

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      
        ~NumPyDocResults.error_count
      
      
        ~NumPyDocResults.errors
      
      
        ~NumPyDocResults.file
      
      
        ~NumPyDocResults.file_line
      
      
        ~NumPyDocResults.ignored_errors
      
   
   